import { BaseEdge, Node, Edge, EdgeLabelRenderer, EdgeProps, getBezierPath, getSmoothStepPath, getStraightPath, Position, useReactFlow, useInternalNode, InternalNode } from '@xyflow/react';

export type GraphEdge = Edge<{ text: string }, 'graph-edge'>;

function getEdgeParams(sourceNode: InternalNode, targetNode: InternalNode) {
    console.log(sourceNode)
    const sourceCenter = {
        x: sourceNode.position.x + sourceNode.width / 2,
        y: sourceNode.position.y + sourceNode.height / 2,
    };
    const targetCenter = {
        x: targetNode.position.x + targetNode.width / 2,
        y: targetNode.position.y + targetNode.height / 2,
    };

    const dx = targetCenter.x - sourceCenter.x;

    // 简化连接逻辑：只基于x轴方向判断
    let sourcePos: Position;
    let targetPos: Position;

    // 如果目标在源节点右边，源节点用右侧连接点，目标节点用左侧连接点
    if (dx > 0) {
        sourcePos = Position.Right;
        targetPos = Position.Left;
    } else {
        // 如果目标在源节点左边，源节点用左侧连接点，目标节点用右侧连接点
        sourcePos = Position.Left;
        targetPos = Position.Right;
    }

    // 使用节点中心的y坐标
    return {
        sourcePos,
        targetPos,
        sx: sourceCenter.x + sourceNode.measured.width / 2,
        sy: sourceCenter.y,
        tx: targetCenter.x - targetNode.measured.width / 2,
        ty: targetCenter.y,
    };
}
export const GraphEdge = ({ id, source, target, sourceX, sourceY, targetX, targetY, data, ...props }: EdgeProps<GraphEdge>) => {
    const sourceNode = useInternalNode(source);
    const targetNode = useInternalNode(target);
    const { sx, sy, tx, ty, targetPos, sourcePos } = getEdgeParams(sourceNode, targetNode)
    const [edgePath, labelX, labelY] = getBezierPath({
        sourceX: sx,
        sourceY: sy,
        targetX: tx,
        targetY: ty,
        sourcePosition: sourcePos,
        targetPosition: targetPos,
        curvature: 0.3,

    });
    return (
        <>
            <BaseEdge
                path={edgePath}
                style={{
                    strokeWidth: 2,
                    stroke: '#b1b1b7',
                    transition: 'stroke 0.3s, stroke-width 0.3s',
                }}
            />
            <EdgeLabelRenderer>
                {data?.text && (
                    <div
                        style={{
                            position: 'absolute',
                            transform: `translate(-50%, -50%) translate(${labelX}px,${labelY}px)`,
                            fontSize: 12,
                            pointerEvents: 'all',
                        }}
                        className="nodrag nopan px-2 py-1 rounded bg-white/80 shadow-sm"
                    >
                        {data.text}
                    </div>
                )}
            </EdgeLabelRenderer>
        </>
    );
};