import { LayoutOptions, LayoutStrategy, NodeWithLayout } from "./types";
import { Edge, Node } from "@xyflow/react";
// 抽象布局类，包含共用的工具方法
export abstract class BaseLayout implements LayoutStrategy {
    protected buildNodeMap(nodes: Node[]): Map<string, NodeWithLayout> {
        const nodeMap = new Map<string, NodeWithLayout>();
        nodes.forEach(node => {
            nodeMap.set(node.id, { ...node, children: [], width: 150, height: 40 });
        });
        return nodeMap;
    }

    protected buildTreeStructure(nodeMap: Map<string, NodeWithLayout>, edges: Edge[]): NodeWithLayout | undefined {
        edges.forEach(edge => {
            const source = nodeMap.get(edge.source);
            const target = nodeMap.get(edge.target);
            if (source && target) {
                source.children?.push(target);
                target.parent = source;
            }
        });
        return Array.from(nodeMap.values()).find(node => !node.parent);
    }

    abstract layout(options: LayoutOptions): { nodes: Node[], edges: Edge[] };
}
