import { Node, Edge } from "@xyflow/react";
import { LayoutOptions, LayoutStrategy } from "./types";
import { TreeLayout } from "./TreeLayout";
import { MindMapLayout } from "./MindMapLayout";
import { SingleMapLayout } from "./SingleMapLayout";

// 布局工厂类
class LayoutFactory {
    static createLayout(type: 'mindmap' | 'tree' | 'force' | 'single'): LayoutStrategy {
        switch (type) {
            case 'mindmap':
                return new MindMapLayout();
            case 'tree':
                return new TreeLayout();
            case 'single':
                return new SingleMapLayout()
            case 'force':
            // return new ForceLayout(); // 待实现
            default:
                return new MindMapLayout();
        }
    }
}

// 导出布局函数
export function getLayout(type: 'mindmap' | 'tree' | 'force' | 'single', options: LayoutOptions) {
    const layoutStrategy = LayoutFactory.createLayout(type);
    return layoutStrategy.layout(options);
}

// 为了保持向后兼容，保留原有的导出
export function getMindMapLayout(options: LayoutOptions) {
    return getLayout("single", options);
}