import { useContext, useState } from "react";
import { Input, Layout, Avatar, Button, Dropdown } from "antd";
import {
	EditFilled,
	HomeOutlined,
	SearchOutlined,
	UserOutlined,
} from "@ant-design/icons";
import { useAuth } from "@web/src/providers/auth-provider";
import { useNavigate, useParams } from "react-router-dom";
import { UserMenu } from "@web/src/app/main/layout/UserMenu/UserMenu";
import { CourseDetailContext } from "../CourseDetailContext";
import { usePost, useStaff } from "@nice/client";
import toast from "react-hot-toast";
import { NavigationMenu } from "@web/src/app/main/layout/NavigationMenu";

const { Header } = Layout;

export function CourseDetailHeader() {
	const { id } = useParams();
	const { isAuthenticated, user, hasSomePermissions, hasEveryPermissions } =
		useAuth();
	const navigate = useNavigate();
	const { course, canEdit, userIsLearning } = useContext(CourseDetailContext);
	const { update } = useStaff();

	return (
		<Header className="select-none  flex items-center justify-center bg-white shadow-md border-b border-gray-100 fixed w-full z-30">
			<div className="w-full  max-w-screen-3xl px-4 md:px-6 flex items-center justify-between h-full">
				<div className="flex items-center space-x-8">
					<div
						onClick={() => navigate("/")}
						className="text-2xl font-bold bg-gradient-to-r from-primary-600 via-primary-500 to-primary-400 bg-clip-text text-transparent hover:scale-105 transition-transform cursor-pointer">
						烽火慕课
					</div>
					<NavigationMenu />
				</div>

				<div className="flex items-center space-x-6">
					{isAuthenticated && (
						<Button
							onClick={async () => {
								if (!userIsLearning) {
									await update.mutateAsync({
										where: { id: user?.id },
										data: {
											learningPosts: {
												connect: { id: course.id },
											},
										},
									});
								} else {
									await update.mutateAsync({
										where: { id: user?.id },
										data: {
											learningPosts: {
												disconnect: {
													id: course.id,
												},
											},
										},
									});
								}
							}}
							className="flex items-center space-x-1 bg-gradient-to-r from-blue-500 to-blue-600 text-white hover:from-blue-600 hover:to-blue-700 border-none shadow-md hover:shadow-lg transition-all"
							icon={<EditFilled />}>
							{userIsLearning ? "退出学习" : "加入学习"}
						</Button>
					)}
					{canEdit && (
						<Button
							onClick={() => {
								const url = id
									? `/course/${id}/editor`
									: "/course/editor";
								navigate(url);
							}}
							className="flex items-center space-x-1 bg-gradient-to-r from-blue-500 to-blue-600 text-white hover:from-blue-600 hover:to-blue-700 border-none shadow-md hover:shadow-lg transition-all"
							icon={<EditFilled />}>
							{"编辑课程"}
						</Button>
					)}
					{isAuthenticated ? (
						<UserMenu />
					) : (
						<Button
							onClick={() => navigate("/login")}
							className="flex items-center space-x-1 bg-gradient-to-r from-blue-500 to-blue-600 text-white hover:from-blue-600 hover:to-blue-700 border-none shadow-md hover:shadow-lg transition-all"
							icon={<UserOutlined />}>
							登录
						</Button>
					)}
				</div>
			</div>
		</Header>
	);
}
